==> react-scss-style-module-1.0.14.tgz: package/src/index.jsx <==
const ReactSCSS = () => {
  const compile = (styles, classes) =>
    classes.map(cls => styles[cls] || cls).join(" ");

  const compileEvents = (styles, events) =>
    Object.values(events)
      .flatMap(eventObj =>
        Object.values(eventObj).map(value => styles[value] || value)
      )
      .join(" ");

  const bind = (styles, opts = {}) => {
    const cls = opts.classes ? opts.classes.split(" ") : [];
    const dflts = opts.defaults ? opts.defaults.split(" ") : [];
    const evts = opts.events ? opts.events.split(" ") : [];
    const compiled = compile(styles, cls);
    const compiledDefaults = compile(styles, dflts);
    const compiledEvents = compileEvents(styles, evts);
    return [compiled, compiledDefaults, compiledEvents].join(" ");
  };

  return { compile, compileEvents, bind };
};

export default ReactSCSS();

// const ReactSCSS = () => {
//   const compile = (styles, classes) =>
//     classes.map(cls => styles[cls] || cls);

//   const compileEvents = (styles, events) =>
//     Object.values(events).flatMap(eventObj =>
//       Object.entries(eventObj).map(([state, value]) => styles[value] || value)
//     );

//   const bind = (styles, opts = {}) => {
//     const cls = opts.classes ? opts.classes.split(" ") : [];
//     const dflts = opts.defaults ? opts.defaults.split(" ") : [];
//     const evts = opts.events ? opts.events.split(" ") : [];
//     const compiled = compile(styles, cls).join(" ");
//     const compiledDefaults = compile(styles, dflts).join(" ");
//     const compiledEvents = compileEvents(styles, evts).join(" ");
//     return [compiled, compiledDefaults, compiledEvents].join(" ");
//   }

//   return { compile, compileEvents, attach };
// }

// export default ReactSCSS();

==> react-scss-style-module-1.0.15.tgz: package/src/index.jsx <==
const ReactSCSS = () => {
  const compile = (styles, classes) =>
    classes.map(cls => styles[cls] || cls).join(" ");

  const compileEvents = (styles, events) =>
    Object.values(events)
      .flatMap(eventObj =>
        Object.values(eventObj).map(value => styles[value] || value)
      )
      .join(" ");

  const bind = (styles, opts = {}) => {
    const cls = opts.classes ? opts.classes.split(" ") : [];
    const dflts = opts.defaults ? opts.defaults.split(" ") : [];
    const evts = opts.events ? opts.events.split(" ") : [];
    const compiled = compile(styles, cls);
    const compiledDefaults = compile(styles, dflts);
    const compiledEvents = compileEvents(styles, evts);
    return [compiled, compiledDefaults, compiledEvents].join(" ").trim();
  };

  return { compile, compileEvents, bind };
};

export default ReactSCSS();

// const ReactSCSS = () => {
//   const compile = (styles, classes) =>
//     classes.map(cls => styles[cls] || cls);

//   const compileEvents = (styles, events) =>
//     Object.values(events).flatMap(eventObj =>
//       Object.entries(eventObj).map(([state, value]) => styles[value] || value)
//     );

//   const bind = (styles, opts = {}) => {
//     const cls = opts.classes ? opts.classes.split(" ") : [];
//     const dflts = opts.defaults ? opts.defaults.split(" ") : [];
//     const evts = opts.events ? opts.events.split(" ") : [];
//     const compiled = compile(styles, cls).join(" ");
//     const compiledDefaults = compile(styles, dflts).join(" ");
//     const compiledEvents = compileEvents(styles, evts).join(" ");
//     return [compiled, compiledDefaults, compiledEvents].join(" ");
//   }

//   return { compile, compileEvents, attach };
// }

// export default ReactSCSS();
